@@ -3,15 +3,15 @@
 # ||                                                                        ||
 # || CipUX Object Layer Class                                               ||
 # ||                                                                        ||
-# || Copyright (C) 2007 - 2009 by Christian Kuelker. All rights reserved!   ||
+# || Copyright (C) 2007 - 2010 by Christian Kuelker. All rights reserved!   ||
 # ||                                                                        ||
 # || License: GNU GPL version 2 or any later version.                       ||
 # ||                                                                        ||
 # +==========================================================================+
-# $Id: Change.pm 4569 2010-01-07 22:29:06Z christian-guest $
-# $Revision: 4569 $
+# $Id: Change.pm 5011 2010-07-30 23:31:16Z christian-guest $
+# $Revision: 5011 $
 # $HeadURL$
-# $Date: 2010-01-07 23:29:06 +0100 (Thu, 07 Jan 2010) $
+# $Date: 2010-07-31 01:31:16 +0200 (Sat, 31 Jul 2010) $
 # $Source$
 
 package CipUX::Object::Action::Attribute::Change;
@@ -33,7 +33,7 @@ use base qw(CipUX::Object::Action);
 
 {    # BEGIN CLASS
 
-    use version; our $VERSION = qv('3.4.0.3');
+    use version; our $VERSION = qv('3.4.0.5');
     use re 'taint';    # Keep data captured by parens tainted
     delete @ENV{qw(PATH IFS CDPATH ENV BASH_ENV)};    # Make %ENV safe
 
@@ -42,10 +42,12 @@ use base qw(CipUX::Object::Action);
     # +======================================================================+
     Readonly::Scalar my $EMPTY_STRING => q{};
     Readonly::Scalar my $auto_hr      => {
-        userPassword    => sub { userPassword(@_) },
-        sambaLMPassword => sub { sambaLMPassword(@_); },
-        sambaNTPassword => sub { sambaNTPassword(@_); },
-        member          => sub { member(@_); },
+        userPassword         => sub { userPassword(@_) },
+        sambaLMPassword      => sub { sambaLMPassword(@_); },
+        sambaNTPassword      => sub { sambaNTPassword(@_); },
+        sambaPwdLastSet      => sub { sambaPwdLastSet(@_); },
+        sambaPasswordHistory => sub { sambaPasswordHistory(@_); },
+        member               => sub { member(@_); },
     };
 
     # +======================================================================+
@@ -210,6 +212,36 @@ use base qw(CipUX::Object::Action);
             $logger->debug( 'attr_hr : ',
                 { filter => \&Dumper, value => $attr_hr } );
 
+            # TODO: consider replacing userPassword or value
+            #       with non generic target
+            if ( not exists $attr_hr->{value}
+                and exists $attr_hr->{userPassword} )
+            {
+                $logger->debug('early set userPassword');
+                $attr_hr->{value} = $attr_hr->{userPassword};
+                my $aval = $target_hr->{$o}->{userPassword};
+                if ( exists $attr_hr->{sambaLMPassword} ) {
+                    $logger->debug('early set sambaLMPassword');
+                    $attr_hr->{sambaLMPassword} = $self->_auto_attr(
+                        {
+                            attr     => 'sambaLMPassword',
+                            aval     => $aval,
+                            value_hr => $value_hr
+                        }
+                    );
+                }
+                if ( exists $attr_hr->{sambaNTPassword} ) {
+                    $logger->debug('early set sambaNTPassword');
+                    $attr_hr->{sambaNTPassword} = $self->_auto_attr(
+                        {
+                            attr     => 'sambaLMPassword',
+                            aval     => $aval,
+                            value_hr => $value_hr
+                        }
+                    );
+                }
+            }
+
             # foreach: member, memberUid
             foreach my $attr ( sort keys %{ $target_hr->{$o} } ) {
                 $logger->debug("target_hr attr: [$attr] (value run)");
@@ -533,6 +565,41 @@ use base qw(CipUX::Object::Action);
 
     }
 
+    sub sambaPasswordHistory {
+
+        # +------------------------------------------------------------------+
+        # | API
+        my ( $self, $arg_r ) = @_;
+        my $logger = get_logger(__PACKAGE__);
+        $logger->debug('BEGIN');
+
+        my $nt
+            = '00000000000000000000000000000000000000000000000000000000000000';
+
+        # +------------------------------------------------------------------+
+        # | API
+        $logger->debug('END');
+        return $nt;
+
+    }
+
+    sub sambaPwdLastSet {
+
+        # +------------------------------------------------------------------+
+        # | API
+        my ( $self, $arg_r ) = @_;
+        my $logger = get_logger(__PACKAGE__);
+        $logger->debug('BEGIN');
+
+        my $e = $self->date_epoch( { today => 1 } );
+
+        # +------------------------------------------------------------------+
+        # | API
+        $logger->debug('END');
+        return $e;
+
+    }
+
     sub member {
 
         # +------------------------------------------------------------------+
@@ -610,7 +677,7 @@ CipUX::Object::Action::Attribute::Change - Object layer class for CipUX
 
 =head1 VERSION
 
-version 3.4.0.3
+version 3.4.0.5
 
 =head1 SYNOPSIS
 
@@ -685,6 +752,14 @@ TODO
 
 TODO
 
+=head2 sambaPasswordHistory
+
+TODO
+
+=head2 sambaPwdLastSet
+
+TODO
+
 =head2 member
 
 TODO
