@@ -8,10 +8,10 @@
 # || License: GNU GPL - GNU General Public License version 2 or any later   ||
 # || version.                                                               ||
 # +==========================================================================+
-# $Id: Create.pm 4569 2010-01-07 22:29:06Z christian-guest $
-# $Revision: 4569 $
+# $Id: Create.pm 5011 2010-07-30 23:31:16Z christian-guest $
+# $Revision: 5011 $
 # $HeadURL$
-# $Date: 2010-01-07 23:29:06 +0100 (Thu, 07 Jan 2010) $
+# $Date: 2010-07-31 01:31:16 +0200 (Sat, 31 Jul 2010) $
 # $Source$
 
 package CipUX::Object::Action::Create;
@@ -34,7 +34,7 @@ use base qw(CipUX::Object::Action);
 
 {    # BEGIN CLASS
 
-    use version; our $VERSION = qv('3.4.0.3');
+    use version; our $VERSION = qv('3.4.0.5');
     use re 'taint';    # Keep data captured by parens tainted
 
     # +======================================================================+
@@ -506,6 +506,15 @@ use base qw(CipUX::Object::Action);
                 my $msg = 'auto: set attr cipuxCreationDate:=';
                 $logger->debug( $msg, $ahref->{$var} );
 
+            }
+            elsif( $var eq 'sambaPwdLastSet'){
+
+                $ahref->{$var} = [];
+                push @{ $ahref->{$var} }, $self->date_epoch( { today => 1 } );
+
+                my $msg = 'auto: set attr sambaPwdLastSet:=';
+                $logger->debug( $msg, $ahref->{$var} );
+
             }
             else {
                 my $msg = 'auto: unknown auto variable';
@@ -876,7 +885,7 @@ CipUX::Object::Action::Create - Object layer class for CipUX
 
 =head1 VERSION
 
-version 3.4.0.3
+version 3.4.0.5
 
 
 =head1 SYNOPSIS
